@@ -123,25 +123,24 @@ available measure are:
 
 =head3 --stoplist FILE
 
-A file containing a list of words to be excluded. This is used in
-the UMLS::SenseRelate::TargetWord module as well as the vector 
-and lesk measures in the UMLS::Similarity package. The format 
-required is one stopword per line, words are in regular expression 
-format. For example:
+A file containing a list of words to be excluded. This is used in the 
+UMLS::SenseRelate::TargetWord module as well as the vector and lesk 
+measures in the UMLS::Similarity package. The format required is one 
+stopword per line, words are in regular expression format. 
 
- /\b[a-zA-Z]\b/
- /\b[aA]board\b/
- /\b[aA]bout\b/
- /\b[aA]bove\b/
- /\b[aA]cross\b/
- /\b[aA]fter\b/
- /\b[aA]gain\b/
+For example:
 
-The sample file, stoplist-nsp.regex, is under the samples directory.
+  /\b[a-zA-Z]\b/
+  /\b[aA]board\b/
+  /\b[aA]bout\b/
+  /\b[aA]bove\b/
+  /\b[aA]cross\b/
+  /\b[aA]fter\b/
+  /\b[aA]gain\b/
 
-We might change this to require two different stoplists in the future;
-one for the senserelate program and the other for the relatedness 
-measures. 
+The sample file, stoplist-nsp.regex, is under the samples directory. We 
+might change this to require two different stoplists in the future; one 
+for the senserelate program and the other for the relatedness measures.
 
 =head3 --trace FILE
 
@@ -835,7 +834,7 @@ sub load_UMLS_SenseRelate {
     $option_hash{"measure"} = $measure;
 
     my $handler = UMLS::SenseRelate::TargetWord->new($umls, $meas, \%option_hash); 
-    die "Unable to create UMLS::Interface object.\n" if(!$handler);
+    die "Unable to create UMLS::SenserRelateTargetWord object.\n" if(!$handler);
     
     return $handler;
     
@@ -1423,7 +1422,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: umls-senserelate.pl,v 1.5 2011/04/04 15:40:42 btmcinnes Exp $';
+    print '$Id: umls-senserelate.pl,v 1.7 2011/04/12 21:16:43 btmcinnes Exp $';
     print "\nCopyright (c) 2010-2011, Ted Pedersen & Bridget McInnes\n";
 }
 
